@@ -1,9 +1,10 @@
 package Pod::Weaver::Section::Name;
 {
-  $Pod::Weaver::Section::Name::VERSION = '4.003';
+  $Pod::Weaver::Section::Name::VERSION = '4.004';
 }
 use Moose;
 with 'Pod::Weaver::Role::Section';
+with 'Pod::Weaver::Role::StringFromComment';
 # ABSTRACT: add a NAME section with abstract (for your Perl module)
 
 use Moose::Autobox;
@@ -24,10 +25,7 @@ sub _get_docname_via_statement {
 sub _get_docname_via_comment {
   my ($self, $ppi_document) = @_;
 
-  return $self->_extract_comment_content(
-    $ppi_document,
-    qr/^\s*#+\s*PODNAME:\s*(.+)$/m,
-  );
+  return $self->_extract_comment_content($ppi_document, 'PODNAME');
 }
 
 sub _get_docname {
@@ -44,10 +42,7 @@ sub _get_docname {
 sub _get_abstract {
   my ($self, $input) = @_;
 
-  my $comment = $self->_extract_comment_content(
-    $input->{ppi_document},
-    qr/^\s*#+\s*ABSTRACT:\s*(.+)$/m,
-  );
+  my $comment = $self->_extract_comment_content($input->{ppi_document}, 'ABSTRACT');
 
   return $comment if $comment;
 
@@ -58,25 +53,6 @@ sub _get_abstract {
   return $abstract;
 }
 
-sub _extract_comment_content {
-  my ($self, $ppi_document, $regex) = @_;
-
-  my $content;
-  my $finder = sub {
-    my $node = $_[1];
-    return 0 unless $node->isa('PPI::Token::Comment');
-    if ( $node->content =~ $regex ) {
-      $content = $1;
-      return 1;
-    }
-    return 0;
-  };
-
-  $ppi_document->find_first($finder);
-
-  return $content;
-}
-
 sub weave_section {
   my ($self, $document, $input) = @_;
 
@@ -116,7 +92,7 @@ Pod::Weaver::Section::Name - add a NAME section with abstract (for your Perl mod
 
 =head1 VERSION
 
-version 4.003
+version 4.004
 
 =head1 OVERVIEW
 
